# Examples

## Show all humanoid descriptions

This example shows all humanoid robot descriptions using Pinocchio and MeshCat:

```
python all_humanoids.py
```

![image](https://github.com/user-attachments/assets/cc3cc4e9-622e-4cc5-b7d1-5a01d22cb827)

## Show all quadruped descriptions

This example shows all quadruped robot descriptions using Pinocchio and MeshCat:

```
python all_quadrupeds.py
```

![image](https://github.com/user-attachments/assets/0de682e5-8b8e-4c9d-856c-386c1aa6214a)
